@@ -2287,7 +2287,7 @@ class Circle:
                  center_color=None, radius_color=None, radius_width=1, text_color=None, text_size=20):
         """Create a circle object using x, y and radius and optional color and width."""
         if len(args) == 1: args = args[0]
-        self.position = args
+        self.position = list(args)
         self.radius = radius
         self.fill = fill
         if color:
